| ======================================================================================================
| 																		devLoot.inc v1.25
| 																	Written By - Devestator
| 
| Description:
|  devLoot is an include file meant to handle any looting situation.  INI is created and auto populated
|   as new items are found.  Change the settings of an item and that action will be taken automatically
|   the next time the item is found.
| 
| USAGE:  This is primarily intended for use in macros.  /call Loot <corpseID>
|   This will automatically loot the specified corpseID, or you can leave corpseID blank and it will
|    loot all corpses within the INI set CorpseRadius.
| 
| v1.25 Update Notes
|  -Corrected a problem that could cause some items on a corpse to be ignored
|  -Changed LootInit routine LootInit(bool silentLoad,string devLootINI)
|  -Added a delay after opening the corpse to help account for lag slowing down the loading of all items
| 
| v1.24 Update Notes
|  -Corrected a typo in moving routine that could sometimes cause it to error out and end the macro
| 
| v1.23 Update Notes
|  -Corrected a few typing errors that could cause problems with loading INIs
|  -Changed a few variable names that were conflicting with other macros
|  -Added [Settings] LootInCombat INI setting, if FALSE and you enter combat while looting it will stop looting
|  -Changed move to corpse routine for greater compatability with all macros.
| 
| v1.22 Update Notes
|  -Corrected some bugs with looting
|  -Made looting routine faster
|  -Changed to devMovement.inc movement routines because /moveto sucks arse
| 
| v1.21 Update Notes
|  -Added INI Setting [Settings] MinValueKeep=0, this setting if set to a value in copper will automatically
|   keep any items above this price.  If they are not in the INI alreayd it will set their settings to SELL.
|   Items below the value threshold will follow their setting or the default settingin the INI
|  
| v1.20 Update Notes
|  -Added a check to make sure the include is properly initialized no matter what sub is called first
|  -Fixed a few looting bugs and checks to ensure higher rate of success at looting
| 
| =======================================================================================================

Sub BuildCorpseArray
	/declare corpseCount			int local
	/declare cArray						int local
	/declare cID							int local
	/declare cCount						int local 0
	/declare sStr							string local
	/declare mReturn					string local
	
	/for cArray 1 to 100
		/varset cpArray[${cArray}] 0
	/next cArray
	/varset corpseCount ${SpawnCount[corpse radius ${corpseRadius} noalert 199]}
	/for cArray 1 to ${corpseCount}
		/varset cID ${Me.NearestSpawn[${cArray},corpse radius ${corpseRadius} noalert 199].ID}
		/if (${cID}) {
			/if (!${Spawn[${cID}].Deity.ID}) {
				/call LootTracker ${cID}
				/varset mReturn ${Macro.Return}
				/if (${mReturn.Equal[FALSE]}) {
					/varcalc cCount ${cCount} + 1
					/varset cpArray[${cCount}] ${cID}
				}
			} else {
				/squelch /alert add 199 ID ${cID}
			}	
		} else {
			/goto :doneBuilding
		}
	/next cArray
	:doneBuilding
/return

Sub BuildINI(string iniBuild)
	/if (!${Defined[iniBuild]}) /declare iniBuild				string local ${lootINI}
	
	/ini ${iniBuild} Settings CorpseRadius ${corpseRadius}
	/ini ${iniBuild} Settings LinkChannel ${linkChannel}
	/ini ${iniBuild} Settings LinkLeave	${linkLeave}
	/ini ${iniBuild} Settings LinkNoDrop ${linkNoDrop}
	/ini ${iniBuild} Settings NoDropDefault ${nodropDefault}
	/ini ${iniBuild} Settings UnknownDefault ${unknownDefault}
	/ini ${iniBuild} Settings MinValueKeep ${minValueKeep}
	/ini ${iniBuild} Settings LootInCombat ${lootInCombat}
		
	/ini ${iniBuild} 0 0 ${unknownDefault}
	/ini ${iniBuild} 1 1 ${unknownDefault}
	/ini ${iniBuild} 2 2 ${unknownDefault}
	/ini ${iniBuild} 3 3 ${unknownDefault}
	/ini ${iniBuild} 4 4 ${unknownDefault}
	/ini ${iniBuild} 5 5 ${unknownDefault}
	/ini ${iniBuild} 6 6 ${unknownDefault}
	/ini ${iniBuild} 7 7 ${unknownDefault}
	/ini ${iniBuild} 8 8 ${unknownDefault}
	/ini ${iniBuild} 9 9 ${unknownDefault}
	/ini ${iniBuild} A A ${unknownDefault}
	/ini ${iniBuild} B B ${unknownDefault}
	/ini ${iniBuild} C C ${unknownDefault}
	/ini ${iniBuild} D D ${unknownDefault}
	/ini ${iniBuild} E E ${unknownDefault}
	/ini ${iniBuild} F F ${unknownDefault}
	/ini ${iniBuild} G G ${unknownDefault}
	/ini ${iniBuild} H H ${unknownDefault}
	/ini ${iniBuild} I I ${unknownDefault}
	/ini ${iniBuild} J J ${unknownDefault}
	/ini ${iniBuild} K K ${unknownDefault}
	/ini ${iniBuild} L L ${unknownDefault}
	/ini ${iniBuild} M M ${unknownDefault}
	/ini ${iniBuild} N N ${unknownDefault}
	/ini ${iniBuild} O O ${unknownDefault}
	/ini ${iniBuild} P P ${unknownDefault}
	/ini ${iniBuild} Q Q ${unknownDefault}
	/ini ${iniBuild} R R ${unknownDefault}
	/ini ${iniBuild} S S ${unknownDefault}
	/ini ${iniBuild} T T ${unknownDefault}
	/ini ${iniBuild} U U ${unknownDefault}
	/ini ${iniBuild} V V ${unknownDefault}
	/ini ${iniBuild} W W ${unknownDefault}
	/ini ${iniBuild} X W ${unknownDefault}
	/ini ${iniBuild} Y Y ${unknownDefault}
	/ini ${iniBuild} Z Z ${unknownDefault}
/return

Sub Close_Packs
	/declare packLoop	int local

	/for packLoop 1 to 8
		/if (${Window[pack${packLoop}].Open}) /itemnotify pack${packLoop} rightmouseup
	/next packLoop
/return

Sub Loot(int corpseID)
	/if (!${Defined[devLootFirstRun]}) /call LootInit
	/if (!${Defined[corpseID]}) /declare corpseID					int local 0
	/if (!${Defined[clArray]}) /declare clArray						int outer 0
	
	/if (${Cursor.ID}) {
		/echo Cannot loot when something is on the Cursor
		/return LOOT_CURSORFULL
	}
	/call LootTrackerClean
	/if (${corpseID}) {
		/call LootCorpse ${corpseID}
		/return ${Macro.Return}
	} else {
		/call BuildCorpseArray
		/for clArray 1 to 100
			/if (${cpArray[${clArray}]}) {
				/call LootCorpse ${cpArray[${clArray}]}
				/if (${Macro.Return.Equal[LOOT_ABORT_COMBAT]}) /return LOOT_ABORT_COMBAT
			} else {
				/goto :doneLooting
			}
		/next clArray
		:doneLooting
	}
/return COMPLETED_SUCCESS

Sub LootBank(string bankerName)
	/if (!${Defined[devLootFirstRun]}) /call LootInit
	/if (!${Defined[bankerName]}) /declare bankerName					string local NULL
	/declare invItem						int local 0
	/declare cItemAction				string local
	/declare bankType						string local BIGB
	/declare bankPrefix					string local Big
	
	/if (${bankerName.NotEqual[NULL]}) {
		/squelch /target ${bankerName}
		/delay 1s ${Target.Name.Find[${bankerName}]}
	} else /if (!${Target.ID} || ${Target.Type.NotEqual[NPC]} || ${Target.Distance} > 19) {
		/squelch /target clear
		/delay 1s !${Target.ID}
		/squelch /target npc
		/delay 1s ${Target.ID}
	}
	/if (${Target.ID} && ${Target.Distance} > 19) {
		/echo You are to far away from the banker to Bank
		/return LOOTBANK_TOOFAR
	} else /if (!${Target.ID}) {
		/echo A banker Target could not be found
		/return LOOTBANK_NOTARGET
	}
	/if (!${Window[BankWnd].Open} && !${Window[BigBankWnd].Open}) {
		/click Right Target
		/delay 5s (${Window[BankWnd].Open} || ${Window[BigBankWnd].Open})
		/if (!${Window[BankWnd].Open} && !${Window[BigBankWnd].Open}) {
			/echo Failed to Open the Bank Window
			/return LOOTBANK_NOWINDOW
		}
	}
	/if (${Cursor.ID}) {
		/autoinv
		/delay 1s !${Cursor.ID}
		/if (${Cursor.ID}) {
			/echo There is something on your Cursor and we cannot get it off, cannot Bank with an Item on your Cursor.
			/return LOOTBANK_CURSORFULL
		}
	}
	/if (${Window[BankWnd].Open}) {
		/varset bankType BW
		/varset bankPrefix
	}
	/for invItem 23 to 30
		/varset cItemAction ${Ini[${lootINI},${InvSlot[${invItem}].Item.Name.Left[1]},${InvSlot[${invItem}].Item.Name},ITEM_NOTFOUND]}
		/if (${cItemAction.Equal[KEEP]}) {
			/shiftkey /itemnotify ${invItem} leftmouseup
			/delay 1s ${Cursor.ID}
			/echo Banking ${Cursor.Name}
			/notify ${bankPrefix}BankWnd ${bankType}_AutoButton leftmouseup
			/delay 1s !${Cursor.ID}
			/if (${Cursor.ID}) {
				/echo There is still an Item on your Cursor, the Bank must be full.
				/autoinv
				/delay 1s !${Cursor.ID}
				/return LOOTBANK_BANKFULL
			}
		}
		/delay 3
	/next invItem
	
	/call Open_Packs
	/for invItem 262 to 342
		/varset cItemAction ${Ini[${lootINI},${InvSlot[${invItem}].Item.Name.Left[1]},${InvSlot[${invItem}].Item.Name},ITEM_NOTFOUND]}
		/if (${cItemAction.Equal[KEEP]}) {
			/shiftkey /itemnotify ${invItem} leftmouseup
			/delay 1s ${Cursor.ID}
			/echo Banking ${Cursor.Name}
			/notify ${bankPrefix}BankWnd ${bankType}_AutoButton leftmouseup
			/delay 1s !${Cursor.ID}
			/if (${Cursor.ID}) {
				/echo There is still an Item on your Cursor, the Bank must be full.
				/autoinv
				/delay 1s !${Cursor.ID}
				/return LOOTBANK_BANKFULL
			}
		}
		/delay 3
	/next invItem
	/call Close_Packs
	/notify ${bankPrefix}BankWnd ${bankType}_DoneButton leftmouseup
/return LOOTBANK_SUCCESS

Sub LootCorpse(int corpseID)
	/if (!${Defined[devLootFirstRun]}) /call LootInit
	/declare cItems									int local
	/declare cItem									int local
	/declare cItemAction						string local
	/declare linkItems							bool local false
	
	/squelch /target ID ${corpseID}
	/delay 1s ${Target.ID}==${corpseID}
	/if (${Target.ID} && ${Target.Type.Equal[Corpse]} && ${Target.ID}==${corpseID}) {
		/if (${Target.Distance} > 15) {
			/call MoveToCorpse ${corpseID} 12
			/if (${Macro.Return.NotEqual[COMPLETED_SUCCESS]}) {
				/return LOOT_${Macro.Return}
			}
			/delay 3
		}
		:lootAttempt
		/loot
		/delay 2s ${Window[LootWnd].Open}
		/delay 1s
		/if (!${Window[LootWnd].Open}) /return LOOT_NOLOOTWINDOW
		/varset cItems ${Corpse.Items}
		/if (${cItems}) {
			| /echo Total Items = ${cItems}
			/for cItem 1 to ${cItems}
				| /echo Item${cItem} - ${Corpse.Item[${cItem}]}
				/varset cItemAction ${Ini[${lootINI},${Corpse.Item[${cItem}].Name.Left[1]},${Corpse.Item[${cItem}]},ITEM_NOTFOUND]}
				/if (${Select[${cItemAction},ITEM_NOTFOUND,KEEP,SELL]}) {
					/if (${cItemAction.Equal[ITEM_NOTFOUND]}) {
						/if (${Corpse.Item[${cItem}].NoDrop}) {
							| /if (${linkNoDrop}) /varset linkItems true
							/varset cItemAction ${nodropDefault}					
						} else {
							/if (${minValueKeep} && ${Corpse.Item[${cItem}].Value}>=${minValueKeep}) {
								/varset cItemAction SELL
							} else {
								/varset cItemAction ${unknownDefault}
							}
						}
						/ini ${lootINI} ${Corpse.Item[${cItem}].Name.Left[1]} "${Corpse.Item[${cItem}]}" ${cItemAction}
						/if (${cItemAction.Equal[DESTROY]}) {
							/call LootItem ${cItem} TRUE left
						} else /if (${cItemAction.Equal[LEAVE]}) {
							/if (${linkLeave} || (${Corpse.Item[${cItem}].NoDrop} && ${linkNoDrop})) /varset linkItems true
						} else {
							/call LootItem ${cItem}
						}
					} else {
						/call LootItem ${cItem}
					}
				} else {
					/if (${minValueKeep} && ${Corpse.Item[${cItem}].Value}>=${minValueKeep}) {
						/call LootItem ${cItem}
					} else /if (${cItemAction.Equal[DESTROY]}) {
						/call LootItem ${cItem} TRUE Left
					} else /if (${cItemAction.Equal[LEAVE]}) {
						/if ((${Corpse.Item[${cItem}].NoDrop} && ${linkNoDrop}) || ${linkLeave}) /varset linkItems TRUE
						| /if (${linkLeave}) /varset linkItems true
					}
				}
				:nextcItem
				/delay 3
			/next cItem
		}
		/if (${linkItems}) {
			/keypress enter
			/delay 2
			/call Type ${linkChannel}
			/delay 2
			/keypress space chat
			/delay 2
			/nomodkey /notify LootWnd LW_BroadcastButton leftmouseup
			/delay 2
			/keypress enter chat
		}
		:closeLootWnd
		/if (${Window[LootWnd].Open}) /nomodkey /notify LootWnd LW_DoneButton leftmouseup
		/delay 2s !${Window[LootWnd]}
		/if (${Window[LootWnd].Open}) /goto :closeLootWnd
		/call LootTracker ${corpseID} TRUE
		/return LOOT_SUCCESS
	} else {
		/return LOOT_NOTARGET
	}
/return LOOT_UNKNOWN

Sub LootInit(bool silentLoad, string devLootIniName)
	/declare devLootVersion			float outer 1.25
	/if (!${Defined[devLootIniName]}) /declare devLootIniName					string local devLoot.ini
	/declare lootINI						string outer ${devLootIniName}
	/declare linkNoDrop					bool outer true
	/declare linkLeave					bool outer true
	/declare unknownDefault			string outer KEEP
	/declare nodropDefault			string outer LEAVE
	/declare corpseRadius				int outer 100
	/declare linkChannel				string outer /g
	/declare devLootFirstRun		bool outer FALSE
	/declare minValueKeep				int outer 0
	/declare cpArray[100]				int outer
	/declare lootInCombat				bool outer FALSE
	
	| /call MovementInit TRUE
	

	/if (${Ini[${lootINI},Settings,CorpseRadius,NULL].Equal[NULL]}) {
		/call BuildINI ${lootINI}
	} else {
		/varset linkNoDrop ${Ini[${lootINI},Settings,LinkNoDrop,${linkNoDrop}]}
		/varset linkLeave ${Ini[${lootINI},Settings,LinkLeave,${linkLeave}]}
		/varset unknownDefault ${Ini[${lootINI},Settings,UnknownDefault,${unknownDefault}]}
		/varset nodropDefault ${Ini[${lootINI},Settings,NoDropDefault,${nodropDefault}]}
		/varset corpseRadius ${Ini[${lootINI},Settings,CorpseRadius,${corpseRadius}]}
		/varset linkChannel ${Ini[${lootINI},Settings,LinkChannel,${linkChannel}]}
		/varset minValueKeep ${Ini[${lootINI},Settings,MinValueKeep,${minValueKeep}]}
		/varset lootInCombat ${Ini[${lootINI},Settings,LootInCombat,${lootInCombat}]}
	}
	/if (!${silentLoad}) {
		/echo >> Initialized devLoot.inc v${devLootVersion} - Written by Devestator
		/echo >> devLoot.inc settings loaded from ${devLootIniName}
	}
/return

Sub LootItem(int itemNum,bool destItem, string mouseKey)
	/if (!${Defined[itemNum]}) /return
	/if (!${Defined[mouseKey]}) /declare mouseKey			string local right
	/if (!${Defined[destItem]}) /declare destItem			bool local false
	/if (${destItem}) /varset mouseKey Left
	/declare isNoDrop						bool local false

	| /echo Looting Item ${itemNum} - ${Corpse.Item[${itemNum}]}
	/varset isNoDrop ${Corpse.Item[${itemNum}].NoDrop}
	/delay 3
	/shiftkey /itemnotify loot${itemNum} ${mouseKey}mouseup
	/delay 3
	/if (${isNoDrop}) {
		:confWindow
		/delay 5s ${Window[ConfirmationDialogBox].Open}
		/nomodkey /notify ConfirmationDialogBox Yes_Button leftmouseup
		/delay 1s !${Window[ConfirmationDialogBox]}
		/if (${Window[ConfirmationDialogBox].Open}) /goto :confWindow
	} else /if (${mouseKey.Equal[Left]}) {
		/delay 2s ${Cursor.ID}
	}	else {
		/delay 2s !${Corpse.Item[${itemNum}].ID}
	}
	/if (${Cursor.ID} && ${destItem}) {
		/destroy
	} else /if (${Cursor.ID}) {
		/autoinv
	}
	/delay 2s !${Cursor.ID}
	/delay 2
	/if (${Cursor.ID}) {
		/echo Your Inventory appears to be full
		/autoinv
	}
/return

Sub LootSell(string merchName)
	/if (!${Defined[devLootFirstRun]}) /call LootInit
	/if (!${Defined[merchName]}) /declare merchName					string local NULL
	/declare invItem						int local 0
	/declare cItemAction				string local
	
	/if (${merchName.NotEqual[NULL]}) {
		/squelch /target ${merchName}
		/delay 1s ${Target.Name.Find[${merchName}]}
	} else /if (!${Target.ID} || ${Target.Type.NotEqual[NPC]} || ${Target.Distance} > 19) {
		/squelch /target clear
		/delay 1s !${Target.ID}
		/squelch /target npc
		/delay 1s ${Target.ID}
	}
	/if (${Target.ID} && ${Target.Distance} > 19) {
		/echo You are to far away from the Merchant to sell
		/return LOOTSELL_TOOFAR
	} else /if (!${Target.ID}) {
		/echo A Merchant Target could not be found
		/return LOOTSELL_NOTARGET
	}
	/if (!${Window[MerchantWnd].Open}) {
		/click Right Target
		/delay 5s ${Window[MerchantWnd].Open}
		/if (!${Window[MerchantWnd].Open}) {
			/echo Failed to Open the Merchant Window
			/return LOOTSELL_NOWINDOW
		}
	}
	/if (${Cursor.ID}) {
		/autoinv
		/delay 1s !${Cursor.ID}
		/if (${Cursor.ID}) /echo There is something on your Cursor and we cannot get it off, If it is meant to be sold it may not get sold.
	}
	/for invItem 23 to 30
		/varset cItemAction ${Ini[${lootINI},${InvSlot[${invItem}].Item.Name.Left[1]},${InvSlot[${invItem}].Item.Name},ITEM_NOTFOUND]}
		/if (${cItemAction.Equal[SELL]}) {
			/itemnotify ${invItem} leftmouseup
			/delay 5
			/echo Selling ${InvSlot[${invItem}].Item.Name}
			/shiftkey /notify MerchantWnd MW_Sell_Button leftmouseup
			/delay 5s !${InvSlot[${invItem}].Item.ID}
		}
		/delay 3
	/next invItem
	
	/call Open_Packs
	/for invItem 262 to 342
		/varset cItemAction ${Ini[${lootINI},${InvSlot[${invItem}].Item.Name.Left[1]},${InvSlot[${invItem}].Item.Name},ITEM_NOTFOUND]}
		/if (${cItemAction.Equal[SELL]}) {
			/itemnotify ${invItem} leftmouseup
			/delay 5
			/echo Selling ${InvSlot[${invItem}].Item.Name}
			/shiftkey /notify MerchantWnd MW_Sell_Button leftmouseup
			/delay 5s !${InvSlot[${invItem}].Item.ID}
		}
		/delay 3
	/next invItem
	/call Close_Packs
	/notify MerchantWnd MW_Done_Button leftmouseup
/return LOOTSELL_SUCCESS

Sub lootstrafePastObstacle
  /keypress forward
  /keypress back hold
  /delay 3
  /keypress back

  /if (${Math.Rand[99]}>50 ) { 
      /keypress strafe_right hold
  } else {
      /keypress strafe_left hold 
  } 
  /delay 1s 
  /keypress strafe_right 
  /keypress strafe_left 
  /keypress forward hold 
/return 

Sub LootTracker(int corpseID,bool addTracker)
	/if (!${Defined[corpseArray]}) /declare corpseArray[1000]							int outer
	/if (!${Defined[addTracker]}) /declare addTracker											bool local false
	/declare ltArray								int local
	
	/if (!${addTracker}) {
		/if (!${Defined[corpseLooted${corpseID}]}) {
			/return FALSE
		} else {
			/return TRUE
		}
	} else {
		/if (!${Defined[corpseLooted${corpseID}]}) /declare corpseLooted${corpseID}			bool outer
		/varset corpseLooted${corpseID} true
		/for ltArray 1 to 1000
			/if (!${corpseArray[${ltArray}]}) {
				/varset corpseArray[${ltArray}] ${corpseID}
				/goto :trackAdded
			}
		/next ltArray
		:trackAdded
		/return TRUE
	}
/return TRUE

Sub LootTrackerClean
	/if (!${Defined[corpseArray]}) {
		/declare corpseArray[1000]							int outer
		/return
	}
	/declare ltcArray								int local
	
	/for ltcArray 1 to 1000
		/if (${corpseArray[${ltcArray}]}) {
			/if (!${Spawn[${corpseArray[${ltcArray}]}].ID} || ${Spawn[${corpseArray[${ltcArray}]}].Type.NotEqual[Corpse]}) {
				/deletevar corpseLooted${corpseArray[${ltcArray}]}
				/varset corpseArray[${ltcArray}] 0
			}
		}
	/next ltcArray
/return

Sub MoveToCorpse(int MoveToID, int StopDistance) 
	/if (!${Defined[MoveToID]} || !${Spawn[${MoveToID}].ID} || ${Spawn[${MoveToID}].Type.NotEqual[Corpse]}) /return
  /if (!(${Defined[StopDistance]})) /declare StopDistance int local 20

  /declare running						int local 0
  /declare distanceNow				float local 
  /declare distanceBefore			float local ${Spawn[${MoveToID}].Distance} 
  /declare distanceModifier		int local 1
  /declare distanceTimer			timer 5 
  /declare strafeAttempts			int local 0
  /declare doorAttempt				bool local false
	/declare moveTimer					timer local 30s
	  
  :moveToCorpse
	/if (${Me.Underwater} || ${Me.FeetWet}) { 
		/squelch /face fast id ${MoveToID}
  } else {
		/squelch /face fast nolook id ${MoveToID} 
	}

  /if (${Spawn[${MoveToID}].Distance}<${StopDistance}) { 
    /keypress forward 
    /return COMPLETED_SUCCESS
  } else /if (!${moveTimer}) {
  	/keypress forward
  	/return ABORT_TIMEOUT
  }
	/if (${Me.CombatState.Equal[COMBAT]} && !${lootInCombat}) {
		/keypress forward
		/return ABORT_COMBAT
	}  
    
  /if (!${distanceTimer}) { 
    /if (${Me.Sneaking}) { 
        /varset distanceModifier 2 
    } else { 
        /varset distanceModifier 1 
    } 

    /varset distanceNow ${Spawn[${MoveToID}].Distance} 
    /if (${Math.Calc[${distanceBefore}-${distanceNow}]}<${Math.Calc[10/${distanceModifier}]} && ${distanceBefore}) {
			/if (!${Me.Stunned} && !${Debuff.Rooted}) {
			  /squelch /doortarget
			  /if (${DoorTarget.Name.Length} && ${DoorTarget.Distance} < 12) {
			  	/if (${Math.Abs[${Me.Heading.Degrees} - ${DoorTarget.HeadingTo.Degrees}]} < 20) {
			  		/keypress FIRST_PERSON_CAMERA
			    	/nomodkey /keypress U hold
			    	/delay 2
			    	/nomodkey /keypress U
			    }
				}
				/if (${strafeAttempts} > 3) {
					/keypress forward
					/return ABORT_STUCK
				} else /if (!${doorAttempt}) {
					/keypress FIRST_PERSON_CAMERA
					/squelch /doortarget
					/nomodkey /keypress U hold
					/delay 2
					/nomodkey /keypress U
					/varset doorAttempt true
				} else {
					/call lootstrafePastObstacle 
					/varcalc strafeAttempts ${strafeAttempts}+1
				}
			} else /if (${Debuff.Rooted}) {
				/mqlog MoveToSpawn:  Movement aborted due to being rooted
				/return ABORT_ROOT
			}         
    }
    
    /varset distanceBefore ${Spawn[${MoveToID}].Distance} 
    /varset distanceTimer 15 
 	} 

  /if (!${running}) { 
      /keypress forward 
      /if (${Spawn[${MoveToID}].Distance}>=${StopDistance}) { 
          /varset running 1 
          /keypress forward hold 
      } 
  } else { 
      /if (${Spawn[${MoveToID}].Distance}<${StopDistance}) { 
          /varset running 0 
          /keypress forward 
      } 
  }
	/doevents
	/goto :moveToCorpse
/return

Sub Open_Packs
	/declare packLoop	int local

	/for packLoop 1 to 8
		/if (${InvSlot[${Math.Calc[${packLoop}+22]}].Item.Container} && !${Window[pack${packLoop}].Open}) /itemnotify pack${packLoop} rightmouseup
		/if (${Window[TradeSkillWnd].Open}) {
			/notify TradeSkillWnd COMBW_ExperimentButton leftmouseup
			/delay 3
		}
	/next packLoop
/return

Sub Type(string InStr) 
   /declare char string local 
   /declare loopctr int local 
   /for loopctr 1 to ${String[${InStr}].Length} 
      /varset char ${String[${InStr}].Mid[${loopctr},1]} 
      /if (!${String[${char}].Length}) { 
         /keypress space chat 
      } else { 
         /keypress ${char} chat 
      } 
   /next loopctr 
/return 